@@ -4,7 +4,7 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.8.2 (2021-06-23)
+ * Version: 5.10.9 (2023-11-15)
  */
 (function () {
     'use strict';
@@ -23,7 +23,7 @@
       };
     };
 
-    var global = tinymce.util.Tools.resolve('tinymce.PluginManager');
+    var global$3 = tinymce.util.Tools.resolve('tinymce.PluginManager');
 
     var hasProPlugin = function (editor) {
       if (editor.hasPlugin('tinymcespellchecker', true)) {
@@ -46,11 +46,11 @@
       return true;
     };
 
-    var global$1 = tinymce.util.Tools.resolve('tinymce.util.Tools');
+    var global$2 = tinymce.util.Tools.resolve('tinymce.util.Tools');
 
-    var global$2 = tinymce.util.Tools.resolve('tinymce.util.URI');
+    var global$1 = tinymce.util.Tools.resolve('tinymce.util.URI');
 
-    var global$3 = tinymce.util.Tools.resolve('tinymce.util.XHR');
+    var global = tinymce.util.Tools.resolve('tinymce.util.XHR');
 
     var fireSpellcheckStart = function (editor) {
       return editor.fire('SpellcheckStart');
@@ -99,7 +99,6 @@
         };
       };
       var getText = function (node) {
-        var txt;
         if (node.nodeType === 3) {
           return node.data;
         }
@@ -109,7 +108,7 @@
         if (isContentEditableFalse(node)) {
           return '\n';
         }
-        txt = '';
+        var txt = '';
         if (blockElementsMap[node.nodeName] || shortEndedElementsMap[node.nodeName]) {
           txt += '\n';
         }
@@ -192,7 +191,7 @@
             match.stencil = callback(match);
           }
           var clone = match.stencil.cloneNode(false);
-          clone.setAttribute('data-mce-index', matchIndex);
+          clone.setAttribute('data-mce-index', '' + matchIndex);
           if (fill) {
             clone.appendChild(dom.doc.createTextNode(fill));
           }
@@ -384,14 +383,14 @@
         };
         var postData = '';
         data[method === 'addToDictionary' ? 'word' : 'text'] = text;
-        global$1.each(data, function (value, key) {
+        global$2.each(data, function (value, key) {
           if (postData) {
             postData += '&';
           }
           postData += key + '=' + encodeURIComponent(value);
         });
-        global$3.send({
-          url: new global$2(pluginUrl).toAbsolute(getRpcUrl(editor)),
+        global.send({
+          url: new global$1(pluginUrl).toAbsolute(getRpcUrl(editor)),
           type: 'post',
           content_type: 'application/x-www-form-urlencoded',
           data: postData,
@@ -459,7 +458,7 @@
     var ignoreWord = function (editor, startedState, textMatcherState, word, spans, all) {
       editor.selection.collapse();
       if (all) {
-        global$1.each(editor.dom.select('span.mce-spellchecker-word'), function (span) {
+        global$2.each(editor.dom.select('span.mce-spellchecker-word'), function (span) {
           if (span.getAttribute('data-mce-word') === word) {
             editor.dom.remove(span, true);
           }
@@ -489,7 +488,7 @@
     };
     var findSpansByIndex = function (editor, index) {
       var spans = [];
-      var nodes = global$1.toArray(editor.getBody().getElementsByTagName('span'));
+      var nodes = global$2.toArray(editor.getBody().getElementsByTagName('span'));
       if (nodes.length) {
         for (var i = 0; i < nodes.length; i++) {
           var nodeIndex = getElmIndex(nodes[i]);
@@ -536,7 +535,7 @@
       fireSpellcheckStart(editor);
     };
 
-    var get = function (editor, startedState, lastSuggestionsState, textMatcherState, currentLanguageState, _url) {
+    var get = function (editor, startedState, lastSuggestionsState, textMatcherState, currentLanguageState) {
       var getWordCharPattern = function () {
         return getSpellcheckerWordcharPattern(editor);
       };
@@ -551,7 +550,7 @@
       };
     };
 
-    var register = function (editor, pluginUrl, startedState, textMatcherState, lastSuggestionsState, currentLanguageState) {
+    var register$1 = function (editor, pluginUrl, startedState, textMatcherState, lastSuggestionsState, currentLanguageState) {
       editor.addCommand('mceSpellCheck', function () {
         spellcheck(editor, pluginUrl, startedState, textMatcherState, lastSuggestionsState, currentLanguageState);
       });
@@ -573,7 +572,7 @@
     var spellcheckerEvents = 'SpellcheckStart SpellcheckEnd';
     var buildMenuItems = function (listName, languageValues) {
       var items = [];
-      global$1.each(languageValues, function (languageValue) {
+      global$2.each(languageValues, function (languageValue) {
         items.push({
           selectable: true,
           text: languageValue.name,
@@ -583,7 +582,7 @@
       return items;
     };
     var getItems = function (editor) {
-      return global$1.map(getLanguages(editor).split(','), function (langPair) {
+      return global$2.map(getLanguages(editor).split(','), function (langPair) {
         var langPairs = langPair.split('=');
         return {
           name: langPairs[0],
@@ -591,7 +590,7 @@
         };
       });
     };
-    var register$1 = function (editor, pluginUrl, startedState, textMatcherState, currentLanguageState, lastSuggestionsState) {
+    var register = function (editor, pluginUrl, startedState, textMatcherState, currentLanguageState, lastSuggestionsState) {
       var languageMenuItems = buildMenuItems('Language', getItems(editor));
       var startSpellchecking = function () {
         spellcheck(editor, pluginUrl, startedState, textMatcherState, lastSuggestionsState, currentLanguageState);
@@ -616,7 +615,7 @@
           return value === currentLanguageState.get();
         },
         fetch: function (callback) {
-          var items = global$1.map(languageMenuItems, function (languageItem) {
+          var items = global$2.map(languageMenuItems, function (languageItem) {
             return {
               type: 'choiceitem',
               value: languageItem.data,
@@ -655,7 +654,7 @@
     var getSuggestions = function (editor, pluginUrl, lastSuggestionsState, startedState, textMatcherState, currentLanguageState, word, spans) {
       var items = [];
       var suggestions = lastSuggestionsState.get().suggestions[word];
-      global$1.each(suggestions, function (suggestion) {
+      global$2.each(suggestions, function (suggestion) {
         items.push({
           text: suggestion,
           onAction: function () {
@@ -712,15 +711,15 @@
     };
 
     function Plugin () {
-      global.add('spellchecker', function (editor, pluginUrl) {
+      global$3.add('spellchecker', function (editor, pluginUrl) {
         if (hasProPlugin(editor) === false) {
           var startedState = Cell(false);
           var currentLanguageState = Cell(getLanguage(editor));
           var textMatcherState = Cell(null);
           var lastSuggestionsState = Cell(null);
-          register$1(editor, pluginUrl, startedState, textMatcherState, currentLanguageState, lastSuggestionsState);
+          register(editor, pluginUrl, startedState, textMatcherState, currentLanguageState, lastSuggestionsState);
           setup(editor, pluginUrl, lastSuggestionsState, startedState, textMatcherState, currentLanguageState);
-          register(editor, pluginUrl, startedState, textMatcherState, lastSuggestionsState, currentLanguageState);
+          register$1(editor, pluginUrl, startedState, textMatcherState, lastSuggestionsState, currentLanguageState);
           return get(editor, startedState, lastSuggestionsState, textMatcherState, currentLanguageState);
         }
       });
