@@ -4,24 +4,24 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.8.2 (2021-06-23)
+ * Version: 5.10.9 (2023-11-15)
  */
 (function () {
     'use strict';
 
-    var global = tinymce.util.Tools.resolve('tinymce.PluginManager');
+    var global$6 = tinymce.util.Tools.resolve('tinymce.PluginManager');
 
-    var global$1 = tinymce.util.Tools.resolve('tinymce.dom.DOMUtils');
+    var global$5 = tinymce.util.Tools.resolve('tinymce.dom.DOMUtils');
 
-    var global$2 = tinymce.util.Tools.resolve('tinymce.EditorManager');
+    var global$4 = tinymce.util.Tools.resolve('tinymce.EditorManager');
 
     var global$3 = tinymce.util.Tools.resolve('tinymce.Env');
 
-    var global$4 = tinymce.util.Tools.resolve('tinymce.util.Delay');
+    var global$2 = tinymce.util.Tools.resolve('tinymce.util.Delay');
 
-    var global$5 = tinymce.util.Tools.resolve('tinymce.util.Tools');
+    var global$1 = tinymce.util.Tools.resolve('tinymce.util.Tools');
 
-    var global$6 = tinymce.util.Tools.resolve('tinymce.util.VK');
+    var global = tinymce.util.Tools.resolve('tinymce.util.VK');
 
     var getTabFocusElements = function (editor) {
       return editor.getParam('tabfocus_elements', ':prev,:next');
@@ -30,40 +30,41 @@
       return editor.getParam('tab_focus', getTabFocusElements(editor));
     };
 
-    var DOM = global$1.DOM;
+    var DOM = global$5.DOM;
     var tabCancel = function (e) {
-      if (e.keyCode === global$6.TAB && !e.ctrlKey && !e.altKey && !e.metaKey) {
+      if (e.keyCode === global.TAB && !e.ctrlKey && !e.altKey && !e.metaKey) {
         e.preventDefault();
       }
     };
     var setup = function (editor) {
       var tabHandler = function (e) {
-        var x, i;
-        if (e.keyCode !== global$6.TAB || e.ctrlKey || e.altKey || e.metaKey || e.isDefaultPrevented()) {
+        var x;
+        if (e.keyCode !== global.TAB || e.ctrlKey || e.altKey || e.metaKey || e.isDefaultPrevented()) {
           return;
         }
         var find = function (direction) {
           var el = DOM.select(':input:enabled,*[tabindex]:not(iframe)');
           var canSelectRecursive = function (e) {
-            return e.nodeName === 'BODY' || e.type !== 'hidden' && e.style.display !== 'none' && e.style.visibility !== 'hidden' && canSelectRecursive(e.parentNode);
+            var castElem = e;
+            return e.nodeName === 'BODY' || castElem.type !== 'hidden' && castElem.style.display !== 'none' && castElem.style.visibility !== 'hidden' && canSelectRecursive(e.parentNode);
           };
           var canSelect = function (el) {
-            return /INPUT|TEXTAREA|BUTTON/.test(el.tagName) && global$2.get(e.id) && el.tabIndex !== -1 && canSelectRecursive(el);
+            return /INPUT|TEXTAREA|BUTTON/.test(el.tagName) && global$4.get(e.id) && el.tabIndex !== -1 && canSelectRecursive(el);
           };
-          global$5.each(el, function (e, i) {
+          global$1.each(el, function (e, i) {
             if (e.id === editor.id) {
               x = i;
               return false;
             }
           });
           if (direction > 0) {
-            for (i = x + 1; i < el.length; i++) {
+            for (var i = x + 1; i < el.length; i++) {
               if (canSelect(el[i])) {
                 return el[i];
               }
             }
           } else {
-            for (i = x - 1; i >= 0; i--) {
+            for (var i = x - 1; i >= 0; i--) {
               if (canSelect(el[i])) {
                 return el[i];
               }
@@ -71,7 +72,7 @@
           }
           return null;
         };
-        var v = global$5.explode(getTabFocus(editor));
+        var v = global$1.explode(getTabFocus(editor));
         if (v.length === 1) {
           v[1] = v[0];
           v[0] = ':prev';
@@ -91,11 +92,11 @@
           }
         }
         if (el) {
-          var focusEditor = global$2.get(el.id || el.name);
+          var focusEditor = global$4.get(el.id || el.name);
           if (el.id && focusEditor) {
             focusEditor.focus();
           } else {
-            global$4.setTimeout(function () {
+            global$2.setTimeout(function () {
               if (!global$3.webkit) {
                 window.focus();
               }
@@ -119,7 +120,7 @@
     };
 
     function Plugin () {
-      global.add('tabfocus', function (editor) {
+      global$6.add('tabfocus', function (editor) {
         setup(editor);
       });
     }
